# Ocyan plugin Wagtail Blog


## Installation
-------------
Add `ocyan.plugin.wagtail_blog` to your projects dependencies.


## Usage
-------------
It gives the ability of making Blog-list page in wagtail and extra two different page types under the blog-list.

## Configuration
There is no need to configure any settings in json

